"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("../lib/command");
const process_1 = require("../utils/process");
const ui_1 = require("../utils/ui");
const path_1 = require("../utils/path");
let Build = class Build {
    async run(args, silent) {
        process.env.NODE_ENV = 'production';
        try {
            await process_1.runProcess('rimraf', ['./dist']);
        }
        catch (e) {
            process_1.handleProcessError(e);
        }
        if (this.analyze) {
            analyze(silent).catch((e) => ui_1.logErrorBold(e));
        }
        else if (this.spa) {
            spa(silent).catch((e) => ui_1.logErrorBold(e));
        }
        else {
            build(silent).catch((e) => ui_1.logErrorBold(e));
        }
    }
};
Build = __decorate([
    command_1.Command({
        name: 'build',
        alias: 'b',
        description: 'Build project for production.',
        options: [
            { flags: '-a, --analyze', description: 'Analyze client bundle.' },
            { flags: '-spa, --spa', description: 'Build only client-side application.' },
        ],
    })
], Build);
exports.Build = Build;
const runWebpack = (configName, silent) => {
    return process_1.runProcess('webpack', ['--mode', 'production', '--config', path_1.packageRoot(`dist/webpack/config/${configName}.js`)], { silent });
};
const build = async (silent) => {
    const promises = [];
    const startTime = Date.now();
    const spinner = new ui_1.Spinner();
    let done = 0;
    const setSpinnerMessage = () => {
        if (done === 3) {
            spinner.message = `Finished building production bundles in ${Date.now() - startTime}ms`;
        }
        else {
            spinner.message = `Building production bundles ${done}/3 ...`;
        }
    };
    if (!silent) {
        spinner.start();
        setSpinnerMessage();
    }
    const run = (configName) => {
        promises.push(runWebpack(configName, true).then(() => {
            done = done + 1;
            setSpinnerMessage();
        }));
    };
    run('client');
    run('server');
    run('isomorphic');
    try {
        await Promise.all(promises);
        if (!silent) {
            spinner.stop();
        }
    }
    catch (e) {
        process_1.handleProcessError(e, spinner);
    }
};
const analyze = async (silent) => {
    process.env.ANALYZE = 'true';
    const startTime = Date.now();
    const spinner = new ui_1.Spinner();
    if (!silent) {
        spinner.start();
        spinner.message = `Start analyzing client bundle...`;
    }
    try {
        await runWebpack('client', true);
    }
    catch (e) {
        process_1.handleProcessError(e, spinner);
    }
    if (!silent) {
        spinner.message = `Analysis finished in ${Date.now() - startTime}ms`;
        spinner.stop();
    }
};
const spa = async (silent) => {
    const startTime = Date.now();
    const spinner = new ui_1.Spinner();
    if (!silent) {
        spinner.start();
        spinner.message = `Start building client bundle only...`;
    }
    try {
        await runWebpack('spa', true);
    }
    catch (e) {
        process_1.handleProcessError(e, spinner);
    }
    if (!silent) {
        spinner.message = `Production build finished in ${Date.now() - startTime}ms`;
        spinner.stop();
    }
};
