"use strict";
const path = require("path");
const Config_1 = require("../../models/Config");
const path_1 = require("../../utils/path");
module.exports = {
    description: 'Add a VueX connected component',
    prompts: [
        {
            type: 'input',
            name: 'name',
            message: 'What should it be called?',
            validate: (value) => {
                if (!value || value.length === 0) {
                    return 'name is required';
                }
                if (value.indexOf('/') === -1) {
                    return 'a connected component has to live in a module';
                }
                return path_1.folderExists(path_1.runtimeRoot(path.join(Config_1.Config.generators.outputDirectory, value)))
                    ? `folder already exists (${value})`
                    : true;
            },
        },
    ],
    actions: (data) => {
        const filePath = data.name.split('/');
        data.componentName = filePath.pop();
        data.moduleName = filePath.pop();
        data.basePath = path.join(process.cwd(), Config_1.Config.generators.outputDirectory, filePath.join('/'));
        return [
            {
                type: 'add',
                path: '{{basePath}}/{{camelCase moduleName}}/{{properCase componentName}}/{{properCase componentName}}.vue',
                templateFile: path.join(process.cwd(), Config_1.Config.generators.blueprintDirectory, 'connected/connected.vue.hbs'),
                abortOnFail: true,
            },
            {
                type: 'add',
                path: '{{basePath}}/{{camelCase moduleName}}/{{properCase componentName}}/{{properCase componentName}}.spec.ts',
                templateFile: path.join(process.cwd(), Config_1.Config.generators.blueprintDirectory, 'connected/connected.spec.ts.hbs'),
                abortOnFail: true,
            },
        ];
    },
};
