"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander = require("commander");
const _ = require("lodash");
const getProperties = (obj) => {
    const result = [];
    for (const property in obj) {
        if (obj.hasOwnProperty(property) &&
            !property.startsWith('_') &&
            ['commands', 'options', 'parent'].indexOf(property) === -1) {
            result.push(property);
        }
    }
    return result;
};
function Command(meta) {
    return (Target) => {
        const target = new Target();
        const command = commander.command(meta.name);
        command.allowUnknownOption();
        if (meta.alias) {
            command.alias(meta.alias);
        }
        if (meta.description) {
            command.description(meta.description);
        }
        if (meta.options) {
            meta.options.forEach((option) => {
                if (option.formatter) {
                    command.option(option.flags, option.description, option.formatter, option.defaultValue);
                }
                else {
                    command.option(option.flags, option.description, option.defaultValue);
                }
            });
        }
        if (meta.arguments) {
            meta.arguments.forEach((arg) => {
                if (arg.required) {
                    command.arguments(`<${arg.name}>`);
                }
                else {
                    command.arguments(`[${arg.name}]`);
                }
            });
        }
        command.action(function () {
            const hasArgs = meta.arguments ? meta.arguments.length > 0 : false;
            const data = hasArgs ? arguments[meta.arguments.length] : arguments[0];
            const options = getProperties(data);
            let args = (data && data.parent && data.parent.rawArgs.splice(3)) || [];
            const silent = !!(data && data.parent && data.parent.silent);
            if (_.isArray(data)) {
                args = data;
            }
            else {
                options.forEach((option) => (target[option] = data[option]));
            }
            if (hasArgs) {
                meta.arguments.forEach((arg, idx) => {
                    target[arg.name] = arguments[idx] ? arguments[idx] : arg.defaultValue;
                });
            }
            target.run(args, silent);
        });
        return target;
    };
}
exports.Command = Command;
