"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = require("axios");
const fs = require("fs");
const https = require("https");
const Config_1 = require("../models/Config");
const path_1 = require("../utils/path");
const ui_1 = require("../utils/ui");
const vueStarterRepo = 'https://api.github.com/repos/devCrossNet/vue-starter';
const deleteFile = (status, filePath) => {
    try {
        fs.unlinkSync(filePath);
        ui_1.logError(`${status}: ${filePath}`);
    }
    catch (e) {
        ui_1.logErrorBold(e.message);
    }
};
const renameFile = (status, oldPath, newPath) => {
    try {
        fs.renameSync(oldPath, newPath);
        ui_1.logInfoBold(`${status}: ${oldPath} --> ${newPath}`);
    }
    catch (e) {
        ui_1.logErrorBold(e.message);
    }
};
const downloadFile = (status, filePath, url) => {
    path_1.ensureDirectoryExists(filePath);
    const file = fs.createWriteStream(filePath);
    const done = () => {
        switch (status) {
            case 'added':
                ui_1.logSuccess(`${status}: ${filePath}`);
                break;
            case 'modified':
                ui_1.log(`${status}: ${filePath}`);
                break;
            default:
                ui_1.log(`${status}: ${filePath}`);
        }
    };
    https
        .get(url, (response) => {
        response.pipe(file);
        file.on('finish', () => {
            file.close();
            done();
        });
    })
        .on('error', () => {
        deleteFile(status, filePath);
    });
};
async function update() {
    try {
        const tagsResponse = await axios_1.default.get(`${vueStarterRepo}/tags`);
        const latestVersion = tagsResponse.data[0].name;
        const currentVersion = Config_1.Config.currentVersion;
        if (latestVersion === currentVersion) {
            ui_1.Result(`Your project is up to date (Version: ${currentVersion}).`);
            return;
        }
        ui_1.Result(`Update from version: ${currentVersion} to version: ${latestVersion}.`);
        const diffResponse = await axios_1.default.get(`${vueStarterRepo}/compare/${currentVersion}...${latestVersion}`);
        const diffFiles = diffResponse.data.files;
        diffFiles.forEach((diffFile) => {
            const dest = path_1.runtimeRoot(diffFile.filename);
            const url = `https://raw.githubusercontent.com/devCrossNet/vue-starter/master/${diffFile.filename}`;
            if (diffFile.status === 'removed') {
                deleteFile(diffFile.status, dest);
            }
            else if (diffFile.status === 'renamed') {
                renameFile(diffFile.status, path_1.runtimeRoot(diffFile.previous_filename), dest);
            }
            else {
                downloadFile(diffFile.status, dest, url);
            }
        });
        Config_1.Config.currentVersion = latestVersion;
        fs.writeFileSync(Config_1.configPath, JSON.stringify(Config_1.Config, null, 2));
    }
    catch (e) {
        ui_1.logErrorBold(e);
    }
}
update();
