"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ui_1 = require("./ui");
const spawn = require('cross-spawn');
const processes = [];
const killProcesses = () => {
    processes.forEach((p) => {
        p.kill();
    });
};
exports.runProcess = (name, args = [], options = {}) => {
    return new Promise((resolve, reject) => {
        const silent = options.silent === undefined ? false : options.silent;
        const localOptions = {
            detached: true,
            cwd: options.cwd ? options.cwd : process.cwd(),
            env: process.env,
        };
        if (!silent) {
            localOptions.stdio = 'inherit';
        }
        const childProcess = spawn(name, args, localOptions);
        let trace = '';
        if (silent) {
            childProcess.stdout.on('data', (data) => {
                trace += data;
            });
            childProcess.stderr.on('data', (data) => {
                trace += data;
            });
        }
        childProcess.on('exit', (code) => {
            if (code === 0) {
                resolve(undefined);
            }
            else {
                const err = { code, trace };
                reject(err);
            }
        });
        childProcess.on('error', () => {
            const err = { code: 1, trace };
            reject(err);
        });
        processes.push(childProcess);
        [
            'SIGHUP',
            'SIGINT',
            'SIGQUIT',
            'SIGUSR1',
            'SIGUSR2',
            'SIGTERM',
            'SIGCONT',
            'SIGILL',
            'SIGTRAP',
            'SIGABRT',
            'SIGBUS',
            'SIGFPE',
            'SIGSEGV',
            'SIGPIPE',
            'SIGALRM',
            'SIGTSTP',
            'SIGTTIN',
            'SIGTTOU',
            'SIGPROF',
            'SIGSYS',
        ].forEach((signal) => {
            process.on(signal, () => {
                killProcesses();
                process.exit(1);
            });
        });
        process.on('uncaughtException', (e) => exports.handleProcessError({ code: 1, trace: e.message }));
    });
};
exports.handleProcessError = (err, spinner = null) => {
    if (spinner) {
        spinner.stop(true);
    }
    ui_1.logError(`Exit with error code: ${err.code}\n\nTrace:\n${err.trace}`);
    killProcesses();
    process.exit(err.code);
};
