"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const webpack = require("webpack");
const utils_1 = require("./utils");
const path_1 = require("../../utils/path");
const { VueLoaderPlugin } = require('vue-loader');
const BundleAnalyzerPlugin = require('webpack-bundle-analyzer').BundleAnalyzerPlugin;
const ForkTsCheckerWebpackPlugin = require('fork-ts-checker-webpack-plugin');
exports.base = {
    stats: {
        assets: true,
        children: true,
    },
    devtool: utils_1.isProd ? false : '#eval-source-map',
    resolve: {
        extensions: ['.ts', '.js', '.vue', '.json', '.node'],
        modules: [
            path_1.runtimeRoot('src'),
            path_1.runtimeRoot('node_modules'),
            path_1.packageRoot('node_modules'),
            path_1.packageRoot('src/webpack/dev'),
        ],
        alias: {
            vue$: 'vue/dist/vue.esm.js',
            '@': path_1.runtimeRoot('src'),
        },
    },
    module: {
        exprContextCritical: false,
        rules: [
            {
                test: /\.ts$/,
                loader: 'ts-loader',
                include: [path_1.runtimeRoot('src'), path_1.packageRoot('src/webpack/dev')],
                exclude: /node_modules/,
                options: {
                    appendTsSuffixTo: [/\.vue$/],
                    transpileOnly: true,
                },
            },
            {
                test: /\.vue$/,
                loader: 'vue-loader',
            },
            {
                test: /\.scss$/,
                rules: [
                    { loader: 'vue-style-loader' },
                    {
                        loader: 'css-loader',
                        exclude: [/global\.scss/],
                        options: {
                            modules: true,
                            importLoaders: 1,
                            localIdentName: '[local]_[hash:base64:8]',
                        },
                    },
                    {
                        loader: 'css-loader',
                        include: [/global\.scss/],
                    },
                    {
                        loader: 'postcss-loader',
                        options: {
                            ident: 'postcss',
                            plugins: () => [
                                require('autoprefixer')({ browsers: ['last 2 versions', 'ie >= 11'] }),
                                require('css-mqpacker')(),
                                require('cssnano')({
                                    discardComments: {
                                        removeAll: true,
                                    },
                                    zindex: false,
                                }),
                            ],
                        },
                    },
                    {
                        loader: 'sass-loader',
                    },
                ],
            },
            {
                test: /\.(?:jpg|png|svg|ttf|woff2?|eot|ico)$/,
                loader: 'file-loader',
                options: {
                    name: '[name].[ext]?[hash]',
                },
            },
            {
                test: /\.css$/,
                loader: ['vue-style-loader', 'css-loader'],
            },
        ],
    },
    plugins: [
        new VueLoaderPlugin(),
        new webpack.DefinePlugin({ PRODUCTION: utils_1.isProd, DEVELOPMENT: utils_1.isDev, TEST: false }),
        new ForkTsCheckerWebpackPlugin({
            tsconfig: path_1.runtimeRoot('tsconfig.json'),
            tslint: path_1.runtimeRoot('tslint.json'),
            vue: true,
        }),
    ],
};
if (utils_1.analyze) {
    exports.base.plugins.push(new BundleAnalyzerPlugin({ analyzerMode: 'static' }));
}
exports.base = require(path_1.runtimeRoot('.vue-starter/webpack.config'))(exports.base);
exports.default = exports.base;
