"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require('path');
const webpack = require('webpack');
const MFS = require('memory-fs');
const clientConfig = nodeRequire(path.resolve(__dirname, '../config/client')).default;
const isomorphicConfig = nodeRequire(path.resolve(__dirname, '../config/isomorphic')).default;
let initialized = false;
let devMiddleware;
let clientCompiler;
let bundle;
let template;
exports.default = (app, callback) => {
    /**
     * Code for hot-reloading
     * ----------------------
     * The dev server and the webpack compilers should just be initialized once.
     * But the middlewares have to be applied every time a new app is loaded.
     */
    if (initialized) {
        app.use(devMiddleware);
        app.use(require('webpack-hot-middleware')(clientCompiler));
        if (bundle && template) {
            callback(bundle, template);
        }
        return;
    }
    clientConfig.entry = ['webpack-hot-middleware/client', clientConfig.entry.app];
    clientConfig.output.filename = '[name].js';
    clientConfig.plugins.push(new webpack.HotModuleReplacementPlugin());
    clientConfig.mode = 'development';
    clientCompiler = webpack(clientConfig);
    devMiddleware = require('webpack-dev-middleware')(clientCompiler, {
        publicPath: clientConfig.output.publicPath,
        stats: {
            colors: true,
            chunks: false,
        },
        watchOptions: {
            aggregateTimeout: 300,
            poll: true,
        },
    });
    app.use(devMiddleware);
    clientCompiler.hooks.done.tap('dev-server', () => {
        const fs = devMiddleware.fileSystem;
        const templatePath = path.join(clientConfig.output.path, 'index.html');
        if (fs.existsSync(templatePath)) {
            template = fs.readFileSync(templatePath, 'utf-8');
            if (bundle) {
                callback(bundle, template);
            }
        }
    });
    app.use(require('webpack-hot-middleware')(clientCompiler));
    isomorphicConfig.mode = 'development';
    const serverCompiler = webpack(isomorphicConfig);
    const mfs = new MFS();
    serverCompiler.outputFileSystem = mfs;
    serverCompiler.watch({}, (err, stats) => {
        if (err) {
            throw err;
        }
        stats = stats.toJson();
        stats.errors.forEach((e) => console.log(JSON.stringify(err, Object.getOwnPropertyNames(e)))); // tslint:disable-line
        stats.warnings.forEach((e) => console.log(JSON.stringify(err, Object.getOwnPropertyNames(e)))); // tslint:disable-line
        const bundlePath = path.join(isomorphicConfig.output.path, 'vue-ssr-bundle.json');
        bundle = JSON.parse(mfs.readFileSync(bundlePath, 'utf-8'));
        if (template) {
            callback(bundle, template);
        }
    });
    initialized = true;
};
